import sys
import platform
import os

from PySide2 import QtWidgets, QtCore
from functools import partial


"""
Dialog includes buttons.
Click on a button will close the dialog and the index of the clicked button
can be retrieved in obj.ret
"""


class SelectButtonDialog(QtWidgets.QDialog):
    def __init__(self, parent=None, message='',
                 button_labels=['test1', 'test2']):
        """
        Create dialog that have buttons from the given labels and show the
            givven message.

        :param parent: QMainWindow/QWidget - the parent widget
        :param message: str - Instruction for user
        :param button_labels: [str,] - list of buttons' labels
        """
        super(SelectButtonDialog, self).__init__(parent)
        self.ret = -1
        height = int(50 * (1 + len(button_labels) / 3))
        self.setGeometry(100, 100, 900, height)
        main_layout = QtWidgets.QVBoxLayout()
        self.setLayout(main_layout)

        label = QtWidgets.QLabel(message)
        main_layout.addWidget(label, 0)

        buttons_layout = QtWidgets.QGridLayout()
        main_layout.addLayout(buttons_layout)
        buttons = []
        r = -1
        for idx, label in enumerate(button_labels):
            c = idx % 3
            if c == 0:
                r += 1
            buttons.append(QtWidgets.QPushButton(label))
            buttons[idx].clicked.connect(partial(self.button_click, idx))
            buttons_layout.addWidget(buttons[idx], r, c)

    @QtCore.Slot()
    def button_click(self, idx):
        """
        When a button is clicked, assign self.ret to the index of the button.
            and close the dialog

        :param idx: int - index of the button
        """
        self.ret = idx
        self.close()


if __name__ == '__main__':
    os_name, version, *_ = platform.platform().split('-')
    if os_name == 'macOS':
        os.environ['QT_MAC_WANTS_LAYER'] = '1'
    app = QtWidgets.QApplication(sys.argv)

    test = SelectButtonDialog(None, "Testing result from buttons",
                              ['test01', 'test02', 'test03',
                               'test11', 'test12', 'test13'])
    test.exec_()

    print("return Code:", test.ret)
    sys.exit(app.exec_())
